#
# spec file for package davfs2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           davfs2
Version:        1.7.0
Release:        4.1
Summary:        FUSE-Filesystem to access WebDAV servers
License:        GPL-3.0-only
Group:          System/Filesystems
URL:            https://savannah.nongnu.org/projects/%{name}
Source0:        https://download.savannah.nongnu.org/releases/%{name}/%{name}-%{version}.tar.gz
Source1:        https://download.savannah.nongnu.org/releases/%{name}/%{name}-%{version}.tar.gz.sig
Source2:        %{name}-rpmlintrc
# Taken from https://savannah.nongnu.org/project/release-gpgkeys.php?group=davfs2&download=1
Source3:        davfs2.keyring
Source4:        davfs2.sysusers
Patch0:         davfs2-1.7.0-neon-33.patch
BuildRequires:  automake >= 1.16
BuildRequires:  fuse-devel >= 2.2
BuildRequires:  neon-devel
BuildRequires:  pwdutils
BuildRequires:  sysuser-tools
Requires:       fuse >= 2.2
Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd
Obsoletes:      fuse-%{name} < %{version}
Provides:       fuse-%{name} = %{version}
%sysusers_requires

%description
davfs2 is a FUSE file system driver that allows mounting a WebDAV server
as a local file system, like a disk drive. This way, applications can access
resources on a Web server without knowing anything about HTTP or WebDAV.

davfs2 runs as a daemon in userspace. It uses the kernel file system "coda", or
FUSE. To connect to the WebDAV server, it makes use of the neon library,
supporting TLS/SSL and access via proxy servers.

%prep
%autosetup -p1

%build
# for davfs2-1.7.0-neon-33.patch
autoreconf -fiv
dav_user="%{name}" \
dav_group="%{name}" \
%configure \
%if 0%{?suse_version} >= 1550
    ssbindir="%{_sbindir}" \
%endif
    --disable-static
%if 0%{?suse_version} >= 1000
PIE="-fPIE"
pie="-pie"
%endif
%make_build AM_CFLAGS="-Wall %{optflags} $PIE" AM_LDFLAGS="$pie"

%install
%make_install
rm -rf "%{buildroot}%{_datadir}/doc"
install -d "%{buildroot}%{_localstatedir}/cache/%{name}"
%find_lang %{name}
rm -rf "%{buildroot}/%{_docdir}"

install -p -D -m0644 %{SOURCE4} %{buildroot}%{_sysusersdir}/%{name}.conf

%sysusers_generate_pre %{buildroot}%{_sysusersdir}/%{name}.conf %{name} %{name}.conf

%pre -f %{name}.pre

%post
%if 0%{?set_permissions:1} > 0
    %set_permissions "%{_sbindir}/mount.davfs"
%else
%if 0%{?run_permissions:1} > 0
    %run_permissions
%endif
%endif

%if 0%{?suse_version} >= 1120
%verifyscript
%verify_permissions -e %{_sbindir}/mount.davfs
%endif

%files -f %{name}.lang
%defattr(-, root, root, 0755)
%license COPYING
%doc AUTHORS BUGS FAQ NEWS README* THANKS TODO etc/%{name}.conf etc/secrets
%{_mandir}/man5/%{name}.conf.5%{?ext_man}
%{_mandir}/man8/mount.davfs.8%{?ext_man}
%{_mandir}/man8/umount.davfs.8%{?ext_man}
%{_mandir}/*/man5/%{name}.conf.5%{?ext_man}
%{_mandir}/*/man8/mount.davfs.8%{?ext_man}
%{_mandir}/*/man8/umount.davfs.8%{?ext_man}
%{_sysusersdir}/%{name}.conf
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config %{_sysconfdir}/%{name}/secrets
%config %{_sysconfdir}/%{name}/certs/
%verify(not user group mode) %attr(0755,root,root) %{_sbindir}/mount.davfs
%{_sbindir}/umount.davfs
%{_datadir}/%{name}
%attr(0750, %{name}, %{name}) %{_localstatedir}/cache/%{name}
%if 0%{?suse_version} < 1550
/sbin/mount.davfs
/sbin/umount.davfs
%endif

%changelog
* Tue May 21 2024 Andreas Stieger <andreas.stieger@gmx.de>
- add davfs2-1.7.0-neon-33.patch to fix build with neon 33
* Mon Feb  5 2024 Paolo Stivanin <info@paolostivanin.com>
- Adapt to RPM 4.19 on Tumbleweed.
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Wed Nov  2 2022 Ali Abdallah <ali.abdallah@suse.com>
- update to 1.7.0:
  * This release uses more portable code.
  * Fix cached file not up to date attributes.
  * Always check for valid prop etag.
- Update davfs2.keyring to match the new upstream one.
* Tue May 24 2022 Dirk Müller <dmueller@suse.com>
- use release team keyring
- enable keyring validating
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 1.6.1:
  * Add Neon version 0.32.
  * mount.davfs.c, get_options: Ignore all unknown options.
  * mount_davfs.c, write_mtab_entry: Add option _netdev to utab-entry.
* Tue Nov 17 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Wed Sep 16 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.6.0
  * Update documentation
  * Remove Coda-support
  * New parser for cookies (bug #58459).
  * Add log message.
  * Add option sharepoint_href_bug.
  * Ignore option -n (sr #110191).
- Remove add-neon-031-support.patch
* Thu Jun 11 2020 Paolo Stivanin <info@paolostivanin.com>
- Add add-neon-031-support.patch
- Add -fcommon to allow building against GCC10
* Tue May  5 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.6
  * Remove call to setuid and setgid.
  * Ignore EEXIST when creating DAV_SYS_RUN (bug #57233).
  * Replace GNU extension 'a' with option 'm' in fscanf
    (bug #56286).
  * Check for inconv.h and iconv (bug #56178).
  * Warning about intermediary CAs (bug #54699).
  * Don't remove cache-files because of inconsistent
    metadata (sr #109587).
  * Add query-string to path on redirect (bug #54943).
  * Ignore option "nofail" (fixes bug #51521).
* Mon Feb 26 2018 jengelh@inai.de
- Replace %%__-type macro indirections. Do not ignore errors from
  useradd. Remove Fedora definitions. Restore debug creation.
  Compact grammar in description.
* Mon Feb 19 2018 dsterba@suse.cz
- spec: update rpmlint, fix build
* Mon Dec  4 2017 chris@computersalat.de
- update to 1.5.4
  * mount.davfs frequently reads /proc/mounts. This is necessary with
    coda but not with fuse. When running two instances of mount.davfs
    using fuse these reads may trigger a kernel bug and create a deadlock.
  * when mount.davfs receives SIGTERM it stops reading from the fuse
    device. In this case kernel fuse will make umount(8) hang forever.
* Fri Sep 11 2015 meissner@suse.com
- remove the setuid root permission files (bsc#907662)
* Fri Jul 17 2015 jthumshirn@suse.com
- Import of davfs2 to SLE12-SP1 from SLE11-SP4 (FATE#318116)
* Tue Nov 25 2014 draht@schaltsekun.de
- upgrade to 1.5.2; changes include:
  * fix for insecure use of system(). This is related to CVE-2014-4362.
  * fixes for usage of symlinks for mountpoints and mtab
  * improved cookie support
  * neon 0.30 support
  * memory leak fixes
  * compiler options for hardened build.
  * load the fuse kernel module automatically.
  * new mount option grpid, trust_ca_cert and trust_server_cert.
  * This list is not exhaustive. Please have a look at the ChangeLog
    for a complete list.
- obsoleted and removed from package:
  * davfs2-fix-formats.patch
  * davfs2-ne_v30.patch
  * davfs2-DESTDIR.patch
  * davfs2-fix_missing_exit_failure.patch
* Sun Dec  1 2013 juergen@spitzmueller.org
- Accept Neon 0.30 (davfs2-ne_v30.patch -- backported from davfs2 cvs:
  http://cvs.savannah.gnu.org/viewvc/davfs2/configure.ac?root=davfs2&r1=1.11.4.1&r2=1.11.4.2)
* Fri Feb 15 2013 conrad@quisquis.de
- Specfile fixes for fedora + SLES
* Wed Feb 13 2013 conrad@quisquis.de
- Added missing file
* Wed Feb 13 2013 conrad@quisquis.de
- Added fix-formats patch to get rid of some warnings
- Added upstream patch for broken symlinks
* Wed Feb 13 2013 conrad@quisquis.de
- Disabled OBS files service - apparently some savannah mirrors are broken
* Wed Feb 13 2013 conrad@quisquis.de
- Upgrade to 1.4.7
- Added -pie/-fPIE compile flags
- Fixed (hopefully) permissions handling
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- User/group addition ought not to be fatal
* Mon Nov 29 2010 pascal.bleser@opensuse.org
- fix location of mount/umount helpers, bnc#640967
- update to 1.4.6:
  * bugfixes
* Mon Nov 30 2009 pascal.bleser@opensuse.org
- update to 1.4.5:
  * option was added to silently refuse to connect when encountering suspicious server certificates
  * several minor bugs were fixed
- changes from 1.4.3:
  * support for Neon 0.29 was added, which also allows for support for NTLM authentication
  * an option was added to silently refuse connections with untrusted server certificates
  * experimental support for the command line option "username" was added for use with pam_mount
* Mon Jun 22 2009 pascal.bleser@opensuse.org
- update to 1.4.1:
  * experimental support was added for the non-standard method USERINFO, which allows this release to get information about available and used Web space from the server
  * failed file upload attempts are now repeated at increasing time intervals
  * if a davfs filesystem is unmounted at disconnect, local changes are cached and submitted at the next mount
  * many other minor improvements and bugfixes were made
* Fri May 29 2009 pascal.bleser@opensuse.org
- copied into filesystems repository in openSUSE Build Service, original in home:leo_eraly
- fix license tag
- added %%%%post script to create davfs2 group and user
- moved to Savannah
- some spec file tidying
- update to 1.4.0
* Wed Jan 14 2009 leo@unstable.be
- Update to release
- Added permissions file (fixes rpmlint error)
* Wed Dec  5 2007 leo@unstable.be
- Fixed Obsoletes and Provides to fix
  https://bugzilla.novell.com/show_bug.cgi?id=332076
* Thu Jul 12 2007 leo@unstable.be
- Initial package. (based on dag's spec)
